==> ejc-labor-impl-3.0.0-20221130.033445-102-sources.jar: com/ejianc/business/labor/bean/AttendanceLogEntity.java <==
package com.ejianc.business.labor.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.util.Date;

/**
 * 考勤日志
 *
 * @author baipengyan
 * @version 1.0
 * @since JDK 1.8
 */
@TableName("ejc_labor_attendance_log")
public class AttendanceLogEntity extends BaseEntity {
	private static final long serialVersionUID = -7355253003420481155L;

	@TableField(value = "worker_id")
	private Long workerId; // 劳务员工id
	@TableField(value = "project_team_id")
	private Long projectTeamId; // 项目班组
	@TableField(value = "project_team_name")
	private String projectTeamName; // 项目班组名称
	@TableField(value = "project_team_inner_code")
	private String projectTeamInnerCode; // 项目班组innerCode
	@TableField(value = "org_team_id")
	private String orgTeamId; // 公司班组
	@TableField(value = "org_team_name")
	private String orgTeamName; // 公司班组名称
	@TableField(value = "org_team_inner_code")
	private String orgTeamInnerCode; // 公司班组innerCode
	@TableField(value = "name")
	private String name; // 姓名
	@TableField(value = "id_card")
	private String idCard; // 身份证号
	@TableField(value = "phone")
	private String phone; // 手机号
	@TableField(value = "team_id")
	private String teamId; // 劳务班组
	@TableField(value = "team_name")
	private String teamName; // 劳务班组名称
	@TableField(value = "project_work_type")
	private Long projectWorkType; // 项目工种
	@TableField(value = "project_work_type_name")
	private String projectWorkTypeName; // 项目工种名称
	@TableField(value = "org_work_type")
	private String orgWorkType; // 公司工种
	@TableField(value = "org_work_type_name")
	private String orgWorkTypeName; // 公司工种名称
	@TableField(value = "org_id")
	private Long orgId; // 组织id
	@TableField(value = "org_name")
	private String orgName; // 组织名称
	@TableField(value = "parent_org_id")
	private Long parentOrgId; // 项目部所属组织id
	@TableField(value = "parent_org_name")
	private String parentOrgName; // 项目部所属组织名称
	@TableField(value = "punch_card_date")
	private Date punchCardDate; // 打卡日期
	@TableField(value = "start_work_time")
	private Date startWorkTime; // 上班时间
	@TableField(value = "start_work_place")
	private String startWorkPlace; // 上班打卡地点
	@TableField(value = "end_work_time")
	private Date endWorkTime; // 下班时间
	@TableField(value = "end_work_place")
	private String endWorkPlace; // 下班打卡地点
	@TableField(value = "duration")
	private String duration; // 时长
	@TableField(value = "attendance_status")
	private String attendanceStatus; // 考勤状态
	@TableField(value = "remote_flag")
	private Integer remoteFlag; // 是否是异地打卡（1:是 0：否）
	@TableField(value = "punch_card_type")
	private String punchCardType; // 打卡类型：上班打卡、下班打卡
	@TableField(value = "project_id")
	private Long projectId; // 项目id
	@TableField(value = "project_name")
	private String projectName; // 项目名称
	@TableField(value = "project_address")
	private String projectAddress; // 项目地址

	public Long getWorkerId() {
		return workerId;
	}

	public void setWorkerId(Long workerId) {
		this.workerId = workerId;
	}

	public Long getProjectTeamId() {
		return projectTeamId;
	}

	public void setProjectTeamId(Long projectTeamId) {
		this.projectTeamId = projectTeamId;
	}

	public String getProjectTeamName() {
		return projectTeamName;
	}

	public void setProjectTeamName(String projectTeamName) {
		this.projectTeamName = projectTeamName;
	}

	public String getProjectTeamInnerCode() {
		return projectTeamInnerCode;
	}

	public void setProjectTeamInnerCode(String projectTeamInnerCode) {
		this.projectTeamInnerCode = projectTeamInnerCode;
	}

	public String getOrgTeamId() {
		return orgTeamId;
	}

	public void setOrgTeamId(String orgTeamId) {
		this.orgTeamId = orgTeamId;
	}

	public String getOrgTeamName() {
		return orgTeamName;
	}

	public void setOrgTeamName(String orgTeamName) {
		this.orgTeamName = orgTeamName;
	}

	public String getOrgTeamInnerCode() {
		return orgTeamInnerCode;
	}

	public void setOrgTeamInnerCode(String orgTeamInnerCode) {
		this.orgTeamInnerCode = orgTeamInnerCode;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getIdCard() {
		return idCard;
	}

	public void setIdCard(String idCard) {
		this.idCard = idCard;
	}

	public String getPhone() {
		return phone;
	}

	public void setPhone(String phone) {
		this.phone = phone;
	}

	public String getTeamId() {
		return teamId;
	}

	public void setTeamId(String teamId) {
		this.teamId = teamId;
	}

	public String getTeamName() {
		return teamName;
	}

	public void setTeamName(String teamName) {
		this.teamName = teamName;
	}

	public Long getProjectWorkType() {
		return projectWorkType;
	}

	public void setProjectWorkType(Long projectWorkType) {
		this.projectWorkType = projectWorkType;
	}

	public String getProjectWorkTypeName() {
		return projectWorkTypeName;
	}

	public void setProjectWorkTypeName(String projectWorkTypeName) {
		this.projectWorkTypeName = projectWorkTypeName;
	}

	public String getOrgWorkType() {
		return orgWorkType;
	}

	public void setOrgWorkType(String orgWorkType) {
		this.orgWorkType = orgWorkType;
	}

	public String getOrgWorkTypeName() {
		return orgWorkTypeName;
	}

	public void setOrgWorkTypeName(String orgWorkTypeName) {
		this.orgWorkTypeName = orgWorkTypeName;
	}

	public Long getOrgId() {
		return orgId;
	}

	public void setOrgId(Long orgId) {
		this.orgId = orgId;
	}

	public String getOrgName() {
		return orgName;
	}

	public void setOrgName(String orgName) {
		this.orgName = orgName;
	}

	public Long getParentOrgId() {
		return parentOrgId;
	}

	public void setParentOrgId(Long parentOrgId) {
		this.parentOrgId = parentOrgId;
	}

	public String getParentOrgName() {
		return parentOrgName;
	}

	public void setParentOrgName(String parentOrgName) {
		this.parentOrgName = parentOrgName;
	}

	public Date getPunchCardDate() {
		return punchCardDate;
	}

	public void setPunchCardDate(Date punchCardDate) {
		this.punchCardDate = punchCardDate;
	}

	public Date getStartWorkTime() {
		return startWorkTime;
	}

	public void setStartWorkTime(Date startWorkTime) {
		this.startWorkTime = startWorkTime;
	}

	public String getStartWorkPlace() {
		return startWorkPlace;
	}

	public void setStartWorkPlace(String startWorkPlace) {
		this.startWorkPlace = startWorkPlace;
	}

	public Date getEndWorkTime() {
		return endWorkTime;
	}

	public void setEndWorkTime(Date endWorkTime) {
		this.endWorkTime = endWorkTime;
	}

	public String getEndWorkPlace() {
		return endWorkPlace;
	}

	public void setEndWorkPlace(String endWorkPlace) {
		this.endWorkPlace = endWorkPlace;
	}

	public String getDuration() {
		return duration;
	}

	public void setDuration(String duration) {
		this.duration = duration;
	}

	public String getAttendanceStatus() {
		return attendanceStatus;
	}

	public void setAttendanceStatus(String attendanceStatus) {
		this.attendanceStatus = attendanceStatus;
	}

	public Integer getRemoteFlag() {
		return remoteFlag;
	}

	public void setRemoteFlag(Integer remoteFlag) {
		this.remoteFlag = remoteFlag;
	}

	public String getPunchCardType() {
		return punchCardType;
	}

	public void setPunchCardType(String punchCardType) {
		this.punchCardType = punchCardType;
	}

	public Long getProjectId() {
		return projectId;
	}

	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}

	public String getProjectName() {
		return projectName;
	}

	public void setProjectName(String projectName) {
		this.projectName = projectName;
	}

	public String getProjectAddress() {
		return projectAddress;
	}

	public void setProjectAddress(String projectAddress) {
		this.projectAddress = projectAddress;
	}
}

==> ejc-labor-impl-3.0.0-20221208.064437-204-sources.jar: com/ejianc/business/labor/bean/AttendanceLogEntity.java <==
package com.ejianc.business.labor.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.util.Date;

/**
 * 考勤日志
 *
 * @author baipengyan
 * @version 1.0
 * @since JDK 1.8
 */
@TableName("ejc_labor_attendance_log")
public class AttendanceLogEntity extends BaseEntity {
	private static final long serialVersionUID = -7355253003420481155L;

	@TableField(value = "worker_id")
	private Long workerId; // 劳务员工id
	@TableField(value = "project_team_id")
	private Long projectTeamId; // 项目班组
	@TableField(value = "project_team_name")
	private String projectTeamName; // 项目班组名称
	@TableField(value = "project_team_inner_code")
	private String projectTeamInnerCode; // 项目班组innerCode
	@TableField(value = "org_team_id")
	private String orgTeamId; // 公司班组
	@TableField(value = "org_team_name")
	private String orgTeamName; // 公司班组名称
	@TableField(value = "org_team_inner_code")
	private String orgTeamInnerCode; // 公司班组innerCode
	@TableField(value = "name")
	private String name; // 姓名
	@TableField(value = "id_card")
	private String idCard; // 身份证号
	@TableField(value = "phone")
	private String phone; // 手机号
	@TableField(value = "team_id")
	private String teamId; // 劳务班组
	@TableField(value = "team_name")
	private String teamName; // 劳务班组名称
	@TableField(value="work_type")
	private String workType; // 项目工种
	@TableField(value="work_type_name")
	private String workTypeName; // 项目工种名称
	@TableField(value = "org_work_type")
	private String orgWorkType; // 公司工种
	@TableField(value = "org_work_type_name")
	private String orgWorkTypeName; // 公司工种名称
	@TableField(value = "org_id")
	private Long orgId; // 组织id
	@TableField(value = "org_name")
	private String orgName; // 组织名称
	@TableField(value = "parent_org_id")
	private Long parentOrgId; // 项目部所属组织id
	@TableField(value = "parent_org_name")
	private String parentOrgName; // 项目部所属组织名称
	@TableField(value = "punch_card_date")
	private Date punchCardDate; // 打卡日期
	@TableField(value = "start_work_time")
	private Date startWorkTime; // 上班时间
	@TableField(value = "start_work_place")
	private String startWorkPlace; // 上班打卡地点
	@TableField(value = "end_work_time")
	private Date endWorkTime; // 下班时间
	@TableField(value = "end_work_place")
	private String endWorkPlace; // 下班打卡地点
	@TableField(value = "duration")
	private Long duration; // 时长
	@TableField(value = "attendance_status")
	private String attendanceStatus; // 考勤状态
	@TableField(value = "remote_flag")
	private Integer remoteFlag; // 是否是异地打卡（1:是 0：否）
	@TableField(value = "punch_card_type")
	private String punchCardType; // 打卡类型：上班打卡、下班打卡
	@TableField(value = "project_id")
	private Long projectId; // 项目id
	@TableField(value = "project_name")
	private String projectName; // 项目名称
	@TableField(value = "project_address")
	private String projectAddress; // 项目地址

	public Long getWorkerId() {
		return workerId;
	}

	public void setWorkerId(Long workerId) {
		this.workerId = workerId;
	}

	public Long getProjectTeamId() {
		return projectTeamId;
	}

	public void setProjectTeamId(Long projectTeamId) {
		this.projectTeamId = projectTeamId;
	}

	public String getProjectTeamName() {
		return projectTeamName;
	}

	public void setProjectTeamName(String projectTeamName) {
		this.projectTeamName = projectTeamName;
	}

	public String getProjectTeamInnerCode() {
		return projectTeamInnerCode;
	}

	public void setProjectTeamInnerCode(String projectTeamInnerCode) {
		this.projectTeamInnerCode = projectTeamInnerCode;
	}

	public String getOrgTeamId() {
		return orgTeamId;
	}

	public void setOrgTeamId(String orgTeamId) {
		this.orgTeamId = orgTeamId;
	}

	public String getOrgTeamName() {
		return orgTeamName;
	}

	public void setOrgTeamName(String orgTeamName) {
		this.orgTeamName = orgTeamName;
	}

	public String getOrgTeamInnerCode() {
		return orgTeamInnerCode;
	}

	public void setOrgTeamInnerCode(String orgTeamInnerCode) {
		this.orgTeamInnerCode = orgTeamInnerCode;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getIdCard() {
		return idCard;
	}

	public void setIdCard(String idCard) {
		this.idCard = idCard;
	}

	public String getPhone() {
		return phone;
	}

	public void setPhone(String phone) {
		this.phone = phone;
	}

	public String getTeamId() {
		return teamId;
	}

	public void setTeamId(String teamId) {
		this.teamId = teamId;
	}

	public String getTeamName() {
		return teamName;
	}

	public void setTeamName(String teamName) {
		this.teamName = teamName;
	}

	public String getWorkType() {
		return workType;
	}

	public void setWorkType(String workType) {
		this.workType = workType;
	}

	public String getWorkTypeName() {
		return workTypeName;
	}

	public void setWorkTypeName(String workTypeName) {
		this.workTypeName = workTypeName;
	}

	public String getOrgWorkType() {
		return orgWorkType;
	}

	public void setOrgWorkType(String orgWorkType) {
		this.orgWorkType = orgWorkType;
	}

	public String getOrgWorkTypeName() {
		return orgWorkTypeName;
	}

	public void setOrgWorkTypeName(String orgWorkTypeName) {
		this.orgWorkTypeName = orgWorkTypeName;
	}

	public Long getOrgId() {
		return orgId;
	}

	public void setOrgId(Long orgId) {
		this.orgId = orgId;
	}

	public String getOrgName() {
		return orgName;
	}

	public void setOrgName(String orgName) {
		this.orgName = orgName;
	}

	public Long getParentOrgId() {
		return parentOrgId;
	}

	public void setParentOrgId(Long parentOrgId) {
		this.parentOrgId = parentOrgId;
	}

	public String getParentOrgName() {
		return parentOrgName;
	}

	public void setParentOrgName(String parentOrgName) {
		this.parentOrgName = parentOrgName;
	}

	public Date getPunchCardDate() {
		return punchCardDate;
	}

	public void setPunchCardDate(Date punchCardDate) {
		this.punchCardDate = punchCardDate;
	}

	public Date getStartWorkTime() {
		return startWorkTime;
	}

	public void setStartWorkTime(Date startWorkTime) {
		this.startWorkTime = startWorkTime;
	}

	public String getStartWorkPlace() {
		return startWorkPlace;
	}

	public void setStartWorkPlace(String startWorkPlace) {
		this.startWorkPlace = startWorkPlace;
	}

	public Date getEndWorkTime() {
		return endWorkTime;
	}

	public void setEndWorkTime(Date endWorkTime) {
		this.endWorkTime = endWorkTime;
	}

	public String getEndWorkPlace() {
		return endWorkPlace;
	}

	public void setEndWorkPlace(String endWorkPlace) {
		this.endWorkPlace = endWorkPlace;
	}

	public Long getDuration() {
		return duration;
	}

	public void setDuration(Long duration) {
		this.duration = duration;
	}

	public String getAttendanceStatus() {
		return attendanceStatus;
	}

	public void setAttendanceStatus(String attendanceStatus) {
		this.attendanceStatus = attendanceStatus;
	}

	public Integer getRemoteFlag() {
		return remoteFlag;
	}

	public void setRemoteFlag(Integer remoteFlag) {
		this.remoteFlag = remoteFlag;
	}

	public String getPunchCardType() {
		return punchCardType;
	}

	public void setPunchCardType(String punchCardType) {
		this.punchCardType = punchCardType;
	}

	public Long getProjectId() {
		return projectId;
	}

	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}

	public String getProjectName() {
		return projectName;
	}

	public void setProjectName(String projectName) {
		this.projectName = projectName;
	}

	public String getProjectAddress() {
		return projectAddress;
	}

	public void setProjectAddress(String projectAddress) {
		this.projectAddress = projectAddress;
	}
}
